aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--draughts/public/javascripts/messages.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/draughts/public/javascripts/messages.js b/draughts/public/javascripts/messages.js
index f532d58..7f70576 100644
--- a/draughts/public/javascripts/messages.js
+++ b/draughts/public/javascripts/messages.js
@@ -1,5 +1,5 @@
(function (exports) {
- exports.START = 0 // Server -> Client :: The game has started
- exports.RESIGN = 1 // Server -> Client :: The opponent resigned
- exports.DISCONNECT = 2 // Server -> Client :: The opponent disconnected
+ exports.START = 0 // Server -> Client :: Inform the client that the game has started
+ exports.RESIGN = 1 // Server <-> Client :: Inform the server/opponent that the client resigned
+ exports.DISCONNECT = 2 // Server -> Client :: Inform the client that the opponent disconnected
})(typeof(exports) == "undefined" ? (this.Messages = {}) : exports)